import genj.gedcom.*;
import genj.report.*;
import java.io.*;

/**
 * GenJ - Report
 * @author Nils Meier nils@meiers.org
 * @version 0.1
 */
public class ReportBirthdays implements Report {

  private static final int MAX = 100000;

  /**
   * Returns the name of this report - should be localized.
   */
  public String getName() {
    return "Birthdays";
  }

  /**
   * Some information about this report
   * @return Information as String
   */
  public String getInfo() {
    return "This report doesn't really do anything - it just loops from 1 to "+MAX+" testing the multitasking of reports";
  }

  /**
   * This method actually starts this report
   */
  public boolean start(ReportView view, Gedcom gedcom, ReportWriter out) throws InterruptedException {

    final String months[] = { "Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
    
    // Calculate Month
    String s = (String)view.getValueFromUser("Please select a month",months,null);
    int month=0;
    for (;month<months.length;month++) {
      if (months[month].equals(s)) {
        break;
      }
    } 
    month++;

    // Show birthdays
    out.println("The following individuals are born in month "+s);

    EntityList indis = gedcom.getEntities(gedcom.INDIVIDUALS);

    for (int i=0;i<indis.getSize();i++) {

      Indi indi = indis.getIndi(i);
      PropertyDate birth = indi.getBirth();
      if (birth==null)
         continue;
      if (birth.getMonth(0,-1) == month) {
        out.println(indi.getName()+" (*"+birth+")");
      }
    }

    // Done
    return true;
  }

  /**
   * Indication of how this reports shows information
   * to the user. Standard Out here only.
   */
  public boolean usesStandardOut() {
    return true;
  }

  /**
   * Author
   */
  public String getAuthor() {
    return "Nils Meier <nils@meiers.org>";
  }
  
  /**
   * Tells wether this report doesn't change information in the Gedcom-file
   */
  public boolean isReadOnly() {
    return true;
  }
}

