import genj.gedcom.*;
import genj.report.*;
import java.io.*;

/**
 * GenJ - Report
 * @author Sven Meier sven@meiers.org
 * @version 0.1
 */
public class ReportEarliestAncestor implements Report {

  /**
   * Returns the nafe of this report - should be localized.
   */
  public String getName() {
    return "Earliest Ancestor";
  }

  /**
   * Some information about this report
   * @return Information as String
   */
  public String getInfo() {
    return "This report prints the earliest ancestor of an individual";
  }

  /**
   * This method actually starts this report
   */
  public boolean start(ReportView view, Gedcom gedcom, ReportWriter out) throws InterruptedException {

    // Calculate id
    String id = "I"+view.getValueFromUser ( "Please enter id number (eg: 1)");
    if (id.length()==0) {
        out.println ("Expected parameter id - Aborting ...");
        return false;
    }

    // Search start individual
    EntityList indis = gedcom.getEntities(Gedcom.INDIVIDUALS);

    // Search earliest
    Indi indi;
    try {
      indi = gedcom.getIndiFromId(id);
    } catch (DuplicateIDException e) {
      out.println ("There are more than one individuals with that ID");
      return false;
    }

    if (indi==null) {
      out.println ("Cannot find this individual.");
    } else {
      // Found earliest
      out.println ("Earliest ancestor of " + indi.getName () + " is:");
      out.println (findEarliest (indi).getName ());
    }

    // Done
    return true;
  }


  /**
   * Finding the earliest ancestor recursive.
   */
  public Indi findEarliest (Indi indi) {

    Indi earliest = indi;
    PropertyDate birth;

    Fam fam = indi.getFamc ();
    if (fam == null){
      return (earliest);
    }

    indi = fam.getHusband ();
    if (indi != null){
      indi = findEarliest (indi);

      birth = indi.getBirth();
      
      if ((birth!=null)&&(birth.compareTo(earliest.getBirth())< 0)) {
        earliest = indi;
      }
    }

    indi = fam.getWife ();
    if (indi != null){
      indi = findEarliest (indi);

      birth = indi.getBirth();

      if ((birth!=null)&&(birth.compareTo(earliest.getBirth())<0)) {
        earliest = indi;
      }
    }

    return (earliest);
  }


  /**
   * Indication of how this reports shows information
   * to the user. Standard Out here only.
   */
  public boolean usesStandardOut() {
    return true;
  }

  /**
   * Author
   */
  public String getAuthor() {
    return "Sven Meier <sven@meiers.org>";
  }
  
  /**
   * Tells wether this report doesn't change information in the Gedcom-file
   */
  public boolean isReadOnly() {
    return true;
  }
}

