import genj.gedcom.*;
import genj.report.*;
import java.io.*;


/**
 * GenJ - Report
 * @author Francois Massonneau <a href="http://www32.gmx.net/cgi-bin/mailnew?CUSTOMERNO=-1&t=&FOLDER=inbox&TO=fmas%40celtes%2Ecom">fmas@celtes.com</a>
 * @version 0.01
 */
public class ReportGedcomStatistics implements Report {

  /**
   * Returns the name of this report - should be localized.
   */
  public String getName() {
    return "Gedcom Statistics";
  }

  /**
   * Some information about this report
   * @return Information as String
   */
  public String getInfo() {
    return "This report gives you some statistics about the current Gedcom File.\n\n            Have Fun and Enjoy";
  }

  /**
   * This method actually starts this report
   */
  public boolean start(ReportView view, Gedcom gedcom, ReportWriter out) throws InterruptedException {

    // Header :
    out.println("This report gives you some statistics about your Family Tree :");
    out.println("     . Number of people,");
    out.println("     . Number of families,");
    out.println("                    -----------------------------");
    out.println("");

    
    // One: We show the number of individuals :
    out.println("In the Gedcom file named '"+gedcom.getName()+"', there are :");
    out.println("     - "+gedcom.getEntities(Gedcom.INDIVIDUALS).getSize()
               +" Individuals (soit : "+gedcom.getEntities(Gedcom.INDIVIDUALS).getSize()+" personnes).");

    // Two: We show the number of families :
    out.println("     - "+gedcom.getEntities(Gedcom.FAMILIES).getSize()
               +" families (soit : "+gedcom.getEntities(Gedcom.FAMILIES).getSize()+" familles).");    

    return true;    
    
  }

  /**
   * Indication of how this reports shows information
   * to the user. Standard Out here only.
   */
  public boolean usesStandardOut() {
    return true;
  }

  /**
   * Author
   */
  public String getAuthor() {
    return "Francois Massonneau &lt;fmas@celtes.com&gt;";
  }

  /**
   * Tells wether this report doesn't change information in the Gedcom-file
   */
  public boolean isReadOnly() {
    return true;
  }

}
